---
html_theme.sidebar_secondary.remove: true
---

# Community

Welcome to the Kaskada community!

The Kaskada project was open-sourced in 2023. As a growing community, we're here to explore new ways to interact with event-based data at scale and have some fun along the way. We build in the open and use the channels below for communication.

```{gallery-grid}
:grid-columns: 1 2 2 3

- header: "{fab}`github;pst-color-primary` GitHub Discussions"
  content: "Ask questions and discuss Kaskada on GitHub."
  link: https://github.com/kaskada-ai/kaskada/discussions
- header: "{fab}`slack;pst-color-primary` Join Slack"
  content: "Join us on Slack to chat about Proactive AI!"
  link: https://join.slack.com/t/kaskada-hq/shared_invite/zt-1t1lms085-bqs2jtGO2TYr9kuuam~c9w
- header: "{fas}`video;pst-color-primary` Meet with Us"
  content: "Schedule time to meet with Kaskada developers and discuss your needs and ideas!"
  link: https://calendly.com/kaskada-io/office-hours
```

## Contributing

Nothing makes us happier than community contributions. See the README in the main Kaskada repository to get a grasp of the project layout and reference the [`CONTRIBUTING.md`](https://github.com/kaskada-ai/kaskada/blob/main/CONTRIBUTING.md){target="_blank" rel="noopener noreferrer"} file for detailed steps.

Use the [GitHub issue tracker](https://github.com/kaskada-ai/kaskada/issues) to file bugs and feature requests.

Acceptance of the DataStax [contributor license agreement (CLA)](https://cla.datastax.com/) is required in order for us to be able to accept your code contribution. You will see this on the standard pull request checklist for the Kaskada repositories.

If you're interested in contributing but don't know where to start, we also recommend looking for a good first issue in the main repository.

## Code of Conduct

To make Kaskada a welcoming and harassment-free experience for everyone, we adopt and follow the [Contributor Covenant](https://www.contributor-covenant.org/).
Please read our [Code of Conduct](https://github.com/kaskada-ai/kaskada/blob/main/CODE_OF_CONDUCT.md) before engaging with the community.